@@ -9,15 +9,15 @@ from sagify.api import build as api_build
 from sagify.commands import ASCII_LOGO
 from sagify.log import logger
 from future.moves import subprocess
+from sagify.config.config import ConfigManager
+import os
 
 click.disable_unicode_literals_warning = True
 
 
 @click.command()
-@click.option(u"-d", u"--dir", required=False, default='.', help="Path to sagify module")
-@click.option(u"-r", u"--requirements-dir", required=True, help="Path to requirements.txt file")
 @click.pass_obj
-def build(obj, dir, requirements_dir):
+def build(obj):
     """
     Command to build SageMaker app
     """
@@ -25,7 +25,17 @@ def build(obj, dir, requirements_dir):
     logger.info("Started building SageMaker Docker image. It will take some minutes...\n")
 
     try:
-        api_build.build(dir=dir, requirements_dir=requirements_dir, docker_tag=obj['docker_tag'])
+        config_file_path = os.path.join('.sagify.json')
+        if not os.path.isfile(config_file_path):
+            raise ValueError()
+
+        config = ConfigManager(config_file_path).get_config()
+        api_build.build(
+            dir=config.sagify_module_dir,
+            requirements_dir=config.requirements_dir,
+            docker_tag=obj['docker_tag'],
+            image_name=config.image_name,
+            python_version=config.python_version)
 
         logger.info("Docker image built successfully!")
     except ValueError:
@@ -36,4 +46,4 @@ def build(obj, dir, requirements_dir):
         raise
     except Exception as e:
         logger.info("{}".format(e))
-        return
+        sys.exit(-1)
