@@ -23,7 +23,18 @@ def _get_local_aws_profiles():
 
 
 def ask_for_app_name():
-    return click.prompt(text="Type in a name for your SageMaker app", type=str)
+    return click.prompt(
+        text="Type in a name for your SageMaker app (Only alphanumeric characters and - are allowed))",
+        type=str
+    )
+
+
+def ask_if_existing_project_exists():
+    return click.confirm(text="Are you starting a new project?")
+
+
+def ask_for_root_dir():
+    return click.prompt(text="Type in the directory where your code lives. Example: src", type=str).strip('/')
 
 
 def ask_for_python_version():
@@ -93,9 +104,12 @@ def ask_for_aws_details():
     return chosen_profile, chosen_region
 
 
+def ask_for_requirements_dir():
+    return click.prompt(text="Type in the path to requirements.txt. Example: requirements.txt", type=str).strip('/')
+
+
 @click.command()
-@click.option(u"-d", u"--dir", required=False, default='.', help="Path to create sagify module")
-def init(dir):
+def init():
     """
     Command to initialize SageMaker template
     """
@@ -103,17 +117,26 @@ def init(dir):
 
     sagify_app_name = ask_for_app_name()
 
+    is_new_project = ask_if_existing_project_exists()
+
+    root_dir = None
+    if not is_new_project:
+        root_dir = ask_for_root_dir()
+
     python_version = ask_for_python_version()
 
     aws_profile, aws_region = ask_for_aws_details()
 
+    requirements_dir = ask_for_requirements_dir()
+
     try:
         api_initialize.init(
-            dir=dir,
             sagify_app_name=sagify_app_name,
             aws_profile=aws_profile,
             aws_region=aws_region,
-            python_version=python_version
+            python_version=python_version,
+            root_dir=root_dir if root_dir else 'src',
+            requirements_dir=requirements_dir
         )
 
         logger.info("\nsagify module is created! ヽ(´▽`)/")
